/**
 * Calculates the number of blank cells before and after a month in a calendar.
 *
 * @param weekdayId - The day of the week of the first day of the month, where
 *                    0 is Sunday, 1 is Monday, ..., 6 is Saturday.
 * @param daysInMonth - The number of days in the month.
 * @returns An object containing the number of blank cells before and after the
 *          month.
 * @example
 * const result = blankCells(3, 31);
 * console.log(result.before); // 3
 * console.log(result.after);  // 1
 */
export declare function blankCells(weekdayId: number, daysInMonth: number): {
    before: number;
    after: number;
};
/**
 * Generates an array of numbers in a specified range.
 *
 * This function returns an array containing all the numbers from the `start`
 * value to the `end` value, inclusive. The `end` value must be greater than
 * the `start` value, otherwise an error is thrown.
 *
 * @param start - The starting number of the range.
 * @param end - The ending number of the range, must be greater than `start`.
 * @returns An array of numbers from `start` to `end`.
 * @throws An error if `end` is not greater than `start`.
 */
export declare function numberRange(start: number, end: number): number[];
export type DayViewOptions = {
    /**
     * Gregorian year
     */
    year: number;
    /**
     * Gregorian month
     */
    month: number;
    /**
     * Gregorian day
     */
    day: number;
    /**
     * Language for output
     *
     * @default English
     */
    lang?: Language;
};
export type MontnViewOptions = {
    /**
     * Gregorian year
     */
    year: number;
    /**
     * Gregorian month
     */
    month: number;
    /**
     * Language for output
     *
     * @default English
     */
    lang?: Language;
};
export type YearViewOptions = {
    /**
     * Gregorian year
     */
    year: number;
    /**
     * Language for output
     *
     * @default English
     */
    lang?: Language;
};
export type DayViewObject = {
    /**
     * Julian Day Number
     */
    jdn: number;
    /**
     * Gregorian Year
     */
    year: {
        /**
         * Gregorian Year in Number
         */
        id: number;
        /**
         * Gregorian Year in string
         */
        str: string | number;
    };
    /**
     * Gregorian Month
     */
    month: {
        /**
         * 1 - 12 [1=Jan,...,12=Dec]
         */
        id: number;
        /**
         * Name of Gregorian Month eg.January
         */
        long: string;
        /**
         * Name of Gregorian Month eg.Jan
         */
        short: string;
        /**
         * Number of days in this month
         */
        days_in_month: number;
    };
    /**
     * Gregorian Day
     */
    day: {
        /**
         * Gregorian Day in Number
         */
        id: number;
        /**
         * Gregorian Day in string
         */
        str: string | number;
    };
    /**
     * Weekday
     */
    weekday: {
        /**
         * Week day index,not related to calculation just for place first day of the month on month-view UI
         *
         * [0=sun , ... , 6=sat]
         */
        index: number;
        /**
         * weekday long
         */
        long: string;
        /**
         * weekday short
         */
        short: string;
    };
    /**
     * Public Holidays Or Not
     */
    isHoliday: boolean;
    /**
     * Is today or not
     */
    isNow: boolean;
    /**
     * Burmese Calendar info
     */
    burmese_cal: {
        /**
         * Sasana Year BE
         */
        sasana_year: {
            id: number;
            str: number | string;
        };
        /**
         * Burmese Year
         */
        burmese_year: {
            id: number;
            str: number | string;
        };
        /**
         * Burmese Month
         */
        burmese_month: {
            index: number;
            str: string;
        };
        /**
         * Moon Phase
         */
        moon_phase: {
            index: number;
            str: string;
        };
        /**
         * Fortnight Day
         */
        fortnight_day: {
            /**
             *  [1 - 15] Or [1 - 14]
             */
            id: number;
            str: string | number;
        };
        /**
         * Burmese Day of a Burmese Month
         */
        burmese_day: {
            /**
             *  [1 - 30] Or [1 - 31]
             */
            id: number;
            str: string | number;
        };
        /**
         * Yatyaza
         */
        yatyaza: {
            /**
             * [0="",1="Yatyaza"]
             */
            index: number;
            str: string;
        };
        /**
         * Pyathada
         */
        pyathada: {
            /**
             * [0="",1="Pyathada",2="Afternoon Pyathada"]
             */
            index: number;
            str: string;
        };
        /**
         * Sabbath
         */
        sabbath: {
            /**
             * [0="",1="Sabbath",2="Sabbath Eve"]
             */
            index: number;
            str: string;
            school_holiday: boolean;
        };
        /**
         * Dragon Head Direction
         */
        nagahle: {
            /**
             * [0="West",1="North",2="East",3="South"]
             */
            index: number;
            str: string;
        };
        /**
         * Mahabote
         */
        mahabote: {
            /**
             * [0="Binga",1= "Ahtun",2="Yaza",3="Adipati",4="Marana",5="Thike",6="Puti"]
             */
            index: number;
            str: string;
        };
        /**
         * Nakhat
         */
        nakhat: {
            /**
             * [0="Ogre",1="Elf",2="Human"]
             */
            index: number;
            str: string;
        };
        /**
         * Array of Astrological days
         */
        astro_days: string[];
        /**
         * Array of Public Holidays
         */
        public_holiday: string[];
    };
};
export type MonthViewObject = {
    /**
     * Gregorian Year
     */
    year: {
        /**
         * Gregorian Year in Number
         */
        id: number;
        /**
         * Gregorian Year in string
         */
        str: string | number;
    };
    /**
     * Gregorian Month
     */
    month: {
        /**
         * 1 - 12 [1=Jan,...,12=Dec]
         */
        id: number;
        /**
         * Name of Gregorian Month eg.January
         */
        long: string;
        /**
         * Name of Gregorian Month eg.Jan
         */
        short: string;
        /**
         * Number of days in this month
         */
        days_in_month: number;
    };
    /**
     * Sasana Year[BE]
     */
    sasana_years: {
        ids: number[];
        str: string[] | number[];
    };
    /**
     * Burmese Year[ME]
     */
    burmese_years: {
        ids: number[];
        str: string[] | number[];
    };
    /**
     * Burmese Month
     */
    burmese_months: {
        index: number[];
        str: string[];
    };
    /**
     * DateViewObjects array
     */
    date_views: Array<DayViewObject>;
};
export type YearViewObject = {
    /**
     * Gregorian Year
     */
    year: {
        /**
         * Gregorian Year in Number
         */
        id: number;
        /**
         * Gregorian Year in string
         */
        str: string | number;
        /**
         * Number of days in this year
         */
        days_in_year: number;
    };
    /**
     * Sasana Year[BE]
     */
    sasana_years: {
        ids: number[];
        str: string[] | number[];
    };
    /**
     * Burmese Year[ME]
     */
    burmese_years: {
        ids: number[];
        str: string[] | number[];
    };
    /**
     * MonthViewObjects array
     */
    month_views: Array<MonthViewObject>;
};
export type CalendarTypes = "gregorian" | "julian";
export type CalendarConvertOptions = {
    ct: CalendarTypes;
    year: number;
    month: number;
    day: number;
};
/**
 * Interface representing the properties of ThinGyan object.
 * Contains YearTo, YearFrom, AkyoDay, AkyaDayTime, AkyatDay, AkyatDay2, AtatDayTime, and NewYearDay.
 */
export interface ThinGyan {
    YearTo: number;
    YearFrom: number;
    AkyoDay: string;
    AkyaDayTime: string;
    AkyatDay: string;
    AkyatDay2: string;
    AtatDayTime: string;
    NewYearDay: string;
    akyatday2: boolean;
}
export type G2JOptions = {
    year: number;
    month: number;
    day: number;
    hour?: number;
    minutes?: number;
    seconds?: number;
    tz?: TimeZones;
};
/**
 * Calculates the offset of the given time zone base on Javascript Date.
 * @param timeZone The time zone to calculate the offset for.
 * @returns The offset in hours between the given time zone and the local time zone.
 */
export declare function getOffset(timeZone: TimeZones): number;
export type TimeZones = "Africa/Abidjan" | "Africa/Accra" | "Africa/Bamako" | "Africa/Banjul" | "Africa/Conakry" | "Africa/Dakar" | "Africa/Freetown" | "Africa/Lome" | "Africa/Nouakchott" | "Africa/Ouagadougou" | "Africa/Timbuktu" | "Atlantic/Reykjavik" | "Atlantic/St_Helena" | "Iceland" | "Africa/Algiers" | "Africa/Bissau" | "Africa/Cairo" | "Egypt" | "Africa/Casablanca" | "Africa/Ceuta" | "Africa/El_Aaiun" | "Africa/Johannesburg" | "Africa/Maseru" | "Africa/Mbabane" | "Africa/Juba" | "Africa/Khartoum" | "Africa/Lagos" | "Africa/Bangui" | "Africa/Brazzaville" | "Africa/Douala" | "Africa/Kinshasa" | "Africa/Libreville" | "Africa/Luanda" | "Africa/Malabo" | "Africa/Niamey" | "Africa/Porto-Novo" | "Africa/Maputo" | "Africa/Blantyre" | "Africa/Bujumbura" | "Africa/Gaborone" | "Africa/Harare" | "Africa/Kigali" | "Africa/Lubumbashi" | "Africa/Lusaka" | "Africa/Monrovia" | "Africa/Nairobi" | "Africa/Addis_Ababa" | "Africa/Asmara" | "Africa/Asmera" | "Africa/Dar_es_Salaam" | "Africa/Djibouti" | "Africa/Kampala" | "Africa/Mogadishu" | "Indian/Antananarivo" | "Indian/Comoro" | "Indian/Mayotte" | "Africa/Ndjamena" | "Africa/Sao_Tome" | "Africa/Tripoli" | "Libya" | "Africa/Tunis" | "Africa/Windhoek" | "America/Adak" | "America/Atka" | "US/Aleutian" | "America/Anchorage" | "US/Alaska" | "America/Araguaina" | "America/Argentina/Buenos_Aires" | "America/Buenos_Aires" | "America/Argentina/Catamarca" | "America/Argentina/ComodRivadavia" | "America/Catamarca" | "America/Argentina/Cordoba" | "America/Cordoba" | "America/Rosario" | "America/Argentina/Jujuy" | "America/Jujuy" | "America/Argentina/La_Rioja" | "America/Argentina/Mendoza" | "America/Mendoza" | "America/Argentina/Rio_Gallegos" | "America/Argentina/Salta" | "America/Argentina/San_Juan" | "America/Argentina/San_Luis" | "America/Argentina/Tucuman" | "America/Argentina/Ushuaia" | "America/Asuncion" | "America/Bahia" | "America/Bahia_Banderas" | "America/Barbados" | "America/Belem" | "America/Belize" | "America/Boa_Vista" | "America/Bogota" | "America/Boise" | "America/Cambridge_Bay" | "America/Campo_Grande" | "America/Cancun" | "America/Caracas" | "America/Cayenne" | "America/Chicago" | "CST6CDT" | "US/Central" | "America/Chihuahua" | "America/Ciudad_Juarez" | "America/Costa_Rica" | "America/Cuiaba" | "America/Danmarkshavn" | "America/Dawson" | "America/Dawson_Creek" | "America/Denver" | "America/Shiprock" | "MST7MDT" | "Navajo" | "US/Mountain" | "America/Detroit" | "US/Michigan" | "America/Edmonton" | "America/Yellowknife" | "Canada/Mountain" | "America/Eirunepe" | "America/El_Salvador" | "America/Fort_Nelson" | "America/Fortaleza" | "America/Glace_Bay" | "America/Goose_Bay" | "America/Grand_Turk" | "America/Guatemala" | "America/Guayaquil" | "America/Guyana" | "America/Halifax" | "Canada/Atlantic" | "America/Havana" | "Cuba" | "America/Hermosillo" | "America/Indiana/Indianapolis" | "America/Fort_Wayne" | "America/Indianapolis" | "US/East-Indiana" | "America/Indiana/Knox" | "America/Knox_IN" | "US/Indiana-Starke" | "America/Indiana/Marengo" | "America/Indiana/Petersburg" | "America/Indiana/Tell_City" | "America/Indiana/Vevay" | "America/Indiana/Vincennes" | "America/Indiana/Winamac" | "America/Inuvik" | "America/Iqaluit" | "America/Pangnirtung" | "America/Jamaica" | "Jamaica" | "America/Juneau" | "America/Kentucky/Louisville" | "America/Louisville" | "America/Kentucky/Monticello" | "America/La_Paz" | "America/Lima" | "America/Los_Angeles" | "PST8PDT" | "US/Pacific" | "America/Maceio" | "America/Managua" | "America/Manaus" | "Brazil/West" | "America/Martinique" | "America/Matamoros" | "America/Mazatlan" | "Mexico/BajaSur" | "America/Menominee" | "America/Merida" | "America/Metlakatla" | "America/Mexico_City" | "Mexico/General" | "America/Miquelon" | "America/Moncton" | "America/Monterrey" | "America/Montevideo" | "America/New_York" | "EST5EDT" | "US/Eastern" | "America/Nome" | "America/Noronha" | "Brazil/DeNoronha" | "America/North_Dakota/Beulah" | "America/North_Dakota/Center" | "America/North_Dakota/New_Salem" | "America/Nuuk" | "America/Godthab" | "America/Ojinaga" | "America/Panama" | "America/Atikokan" | "America/Cayman" | "America/Coral_Harbour" | "EST" | "America/Paramaribo" | "America/Phoenix" | "America/Creston" | "MST" | "US/Arizona" | "America/Port-au-Prince" | "America/Porto_Velho" | "America/Puerto_Rico" | "America/Anguilla" | "America/Antigua" | "America/Aruba" | "America/Blanc-Sablon" | "America/Curacao" | "America/Dominica" | "America/Grenada" | "America/Guadeloupe" | "America/Kralendijk" | "America/Lower_Princes" | "America/Marigot" | "America/Montserrat" | "America/Port_of_Spain" | "America/St_Barthelemy" | "America/St_Kitts" | "America/St_Lucia" | "America/St_Thomas" | "America/St_Vincent" | "America/Tortola" | "America/Virgin" | "America/Punta_Arenas" | "America/Rankin_Inlet" | "America/Recife" | "America/Regina" | "Canada/Saskatchewan" | "America/Resolute" | "America/Rio_Branco" | "America/Porto_Acre" | "Brazil/Acre" | "America/Santarem" | "America/Santiago" | "Chile/Continental" | "America/Santo_Domingo" | "America/Sao_Paulo" | "Brazil/East" | "America/Scoresbysund" | "America/Sitka" | "America/St_Johns" | "Canada/Newfoundland" | "America/Swift_Current" | "America/Tegucigalpa" | "America/Thule" | "America/Tijuana" | "America/Ensenada" | "America/Santa_Isabel" | "Mexico/BajaNorte" | "America/Toronto" | "America/Montreal" | "America/Nassau" | "America/Nipigon" | "America/Thunder_Bay" | "Canada/Eastern" | "America/Vancouver" | "Canada/Pacific" | "America/Whitehorse" | "Canada/Yukon" | "America/Winnipeg" | "America/Rainy_River" | "Canada/Central" | "America/Yakutat" | "Antarctica/Casey" | "Antarctica/Davis" | "Antarctica/Macquarie" | "Antarctica/Mawson" | "Antarctica/Palmer" | "Antarctica/Rothera" | "Antarctica/Troll" | "Antarctica/Vostok" | "Asia/Almaty" | "Asia/Amman" | "Asia/Anadyr" | "Asia/Aqtau" | "Asia/Aqtobe" | "Asia/Ashgabat" | "Asia/Ashkhabad" | "Asia/Atyrau" | "Asia/Baghdad" | "Asia/Baku" | "Asia/Bangkok" | "Asia/Phnom_Penh" | "Asia/Vientiane" | "Indian/Christmas" | "Asia/Barnaul" | "Asia/Beirut" | "Asia/Bishkek" | "Asia/Chita" | "Asia/Colombo" | "Asia/Damascus" | "Asia/Dhaka" | "Asia/Dacca" | "Asia/Dili" | "Asia/Dubai" | "Asia/Muscat" | "Indian/Mahe" | "Indian/Reunion" | "Asia/Dushanbe" | "Asia/Famagusta" | "Asia/Gaza" | "Asia/Hebron" | "Asia/Ho_Chi_Minh" | "Asia/Saigon" | "Asia/Hong_Kong" | "Hongkong" | "Asia/Hovd" | "Asia/Irkutsk" | "Asia/Jakarta" | "Asia/Jayapura" | "Asia/Jerusalem" | "Asia/Tel_Aviv" | "Israel" | "Asia/Kabul" | "Asia/Kamchatka" | "Asia/Karachi" | "Asia/Kathmandu" | "Asia/Katmandu" | "Asia/Khandyga" | "Asia/Kolkata" | "Asia/Calcutta" | "Asia/Krasnoyarsk" | "Asia/Kuching" | "Asia/Brunei" | "Asia/Macau" | "Asia/Macao" | "Asia/Magadan" | "Asia/Makassar" | "Asia/Ujung_Pandang" | "Asia/Manila" | "Asia/Nicosia" | "Europe/Nicosia" | "Asia/Novokuznetsk" | "Asia/Novosibirsk" | "Asia/Omsk" | "Asia/Oral" | "Asia/Pontianak" | "Asia/Pyongyang" | "Asia/Qatar" | "Asia/Bahrain" | "Asia/Qostanay" | "Asia/Qyzylorda" | "Asia/Riyadh" | "Antarctica/Syowa" | "Asia/Aden" | "Asia/Kuwait" | "Asia/Sakhalin" | "Asia/Samarkand" | "Asia/Seoul" | "ROK" | "Asia/Shanghai" | "Asia/Chongqing" | "Asia/Chungking" | "Asia/Harbin" | "PRC" | "Asia/Singapore" | "Asia/Kuala_Lumpur" | "Singapore" | "Asia/Srednekolymsk" | "Asia/Taipei" | "ROC" | "Asia/Tashkent" | "Asia/Tbilisi" | "Asia/Tehran" | "Iran" | "Asia/Thimphu" | "Asia/Thimbu" | "Asia/Tokyo" | "Japan" | "Asia/Tomsk" | "Asia/Ulaanbaatar" | "Asia/Choibalsan" | "Asia/Ulan_Bator" | "Asia/Urumqi" | "Asia/Kashgar" | "Asia/Ust-Nera" | "Asia/Vladivostok" | "Asia/Yakutsk" | "Asia/Yangon" | "Asia/Rangoon" | "Indian/Cocos" | "Asia/Yekaterinburg" | "Asia/Yerevan" | "Atlantic/Azores" | "Atlantic/Bermuda" | "Atlantic/Canary" | "Atlantic/Cape_Verde" | "Atlantic/Faroe" | "Atlantic/Faeroe" | "Atlantic/Madeira" | "Atlantic/South_Georgia" | "Atlantic/Stanley" | "Australia/Adelaide" | "Australia/South" | "Australia/Brisbane" | "Australia/Queensland" | "Australia/Broken_Hill" | "Australia/Yancowinna" | "Australia/Darwin" | "Australia/North" | "Australia/Eucla" | "Australia/Hobart" | "Australia/Currie" | "Australia/Tasmania" | "Australia/Lindeman" | "Australia/Lord_Howe" | "Australia/LHI" | "Australia/Melbourne" | "Australia/Victoria" | "Australia/Perth" | "Australia/West" | "Australia/Sydney" | "Australia/ACT" | "Australia/Canberra" | "Australia/NSW" | "Etc/GMT" | "Etc/GMT+0" | "Etc/GMT-0" | "Etc/GMT0" | "Etc/Greenwich" | "GMT" | "GMT+0" | "GMT-0" | "GMT0" | "Greenwich" | "Etc/GMT-1" | "Etc/GMT-10" | "Etc/GMT-11" | "Etc/GMT-12" | "Etc/GMT-13" | "Etc/GMT-14" | "Etc/GMT-2" | "Etc/GMT-3" | "Etc/GMT-4" | "Etc/GMT-5" | "Etc/GMT-6" | "Etc/GMT-7" | "Etc/GMT-8" | "Etc/GMT-9" | "Etc/GMT+1" | "Etc/GMT+10" | "Etc/GMT+11" | "Etc/GMT+12" | "Etc/GMT+2" | "Etc/GMT+3" | "Etc/GMT+4" | "Etc/GMT+5" | "Etc/GMT+6" | "Etc/GMT+7" | "Etc/GMT+8" | "Etc/GMT+9" | "Etc/UTC" | "Etc/UCT" | "Etc/Universal" | "Etc/Zulu" | "UCT" | "UTC" | "Universal" | "Zulu" | "Europe/Andorra" | "Europe/Astrakhan" | "Europe/Athens" | "EET" | "Europe/Belgrade" | "Europe/Ljubljana" | "Europe/Podgorica" | "Europe/Sarajevo" | "Europe/Skopje" | "Europe/Zagreb" | "Europe/Berlin" | "Arctic/Longyearbyen" | "Atlantic/Jan_Mayen" | "Europe/Copenhagen" | "Europe/Oslo" | "Europe/Stockholm" | "Europe/Brussels" | "CET" | "Europe/Amsterdam" | "Europe/Luxembourg" | "MET" | "Europe/Bucharest" | "Europe/Budapest" | "Europe/Chisinau" | "Europe/Tiraspol" | "Europe/Dublin" | "Eire" | "Europe/Gibraltar" | "Europe/Helsinki" | "Europe/Mariehamn" | "Europe/Istanbul" | "Asia/Istanbul" | "Turkey" | "Europe/Kaliningrad" | "Europe/Kirov" | "Europe/Kyiv" | "Europe/Kiev" | "Europe/Uzhgorod" | "Europe/Zaporozhye" | "Europe/Lisbon" | "Portugal" | "WET" | "Europe/London" | "Europe/Belfast" | "Europe/Guernsey" | "Europe/Isle_of_Man" | "Europe/Jersey" | "GB" | "GB-Eire" | "Europe/Madrid" | "Europe/Malta" | "Europe/Minsk" | "Europe/Moscow" | "W-SU" | "Europe/Paris" | "Europe/Monaco" | "Europe/Prague" | "Europe/Bratislava" | "Europe/Riga" | "Europe/Rome" | "Europe/San_Marino" | "Europe/Vatican" | "Europe/Samara" | "Europe/Saratov" | "Europe/Simferopol" | "Europe/Sofia" | "Europe/Tallinn" | "Europe/Tirane" | "Europe/Ulyanovsk" | "Europe/Vienna" | "Europe/Vilnius" | "Europe/Volgograd" | "Europe/Warsaw" | "Poland" | "Europe/Zurich" | "Europe/Busingen" | "Europe/Vaduz" | "Indian/Chagos" | "Indian/Maldives" | "Indian/Kerguelen" | "Indian/Mauritius" | "Pacific/Apia" | "Pacific/Auckland" | "Antarctica/McMurdo" | "Antarctica/South_Pole" | "NZ" | "Pacific/Bougainville" | "Pacific/Chatham" | "NZ-CHAT" | "Pacific/Easter" | "Chile/EasterIsland" | "Pacific/Efate" | "Pacific/Fakaofo" | "Pacific/Fiji" | "Pacific/Galapagos" | "Pacific/Gambier" | "Pacific/Guadalcanal" | "Pacific/Pohnpei" | "Pacific/Ponape" | "Pacific/Guam" | "Pacific/Saipan" | "Pacific/Honolulu" | "HST" | "Pacific/Johnston" | "US/Hawaii" | "Pacific/Kanton" | "Pacific/Enderbury" | "Pacific/Kiritimati" | "Pacific/Kosrae" | "Pacific/Kwajalein" | "Kwajalein" | "Pacific/Marquesas" | "Pacific/Nauru" | "Pacific/Niue" | "Pacific/Norfolk" | "Pacific/Noumea" | "Pacific/Pago_Pago" | "Pacific/Midway" | "Pacific/Samoa" | "US/Samoa" | "Pacific/Palau" | "Pacific/Pitcairn" | "Pacific/Port_Moresby" | "Antarctica/DumontDUrville" | "Pacific/Chuuk" | "Pacific/Truk" | "Pacific/Yap" | "Pacific/Rarotonga" | "Pacific/Tahiti" | "Pacific/Tarawa" | "Pacific/Funafuti" | "Pacific/Majuro" | "Pacific/Wake" | "Pacific/Wallis" | "Pacific/Tongatapu";
export declare const timeZones: string[];
export type Language = "English" | "Burmese";
export type MoonPhases = 0 | 0.25 | 0.5 | 0.75;
export declare class BcMoon {
    /**
     * Normalize an angle to the range of 0 to 359 degrees.
     *
     * This function takes a number representing an angle and returns its equivalent
     * angle within the range of 0 to 359 degrees by performing a modulus operation.
     * If the resulting angle is negative, it adjusts to ensure a positive value.
     *
     * @param f - The angle in degrees to be normalized.
     * @returns The normalized angle within the range of 0 to 359 degrees.
     */
    private mod360;
    /**
     * Calculate the cycle number for a given month and year.
     *
     * The cycle number is used to find the moon phase. It is calculated by estimating
     * the fraction of the year represented by the given month and adding it to the
     * given year. The result is then multiplied by 12.3685 and subtracted by 2000.
     *
     * @param year - The year.
     * @param month - The month, 1-12.
     * @returns The cycle number.
     */
    private getCycle;
    /**
     * Calculate the Julian Ephemeris Day (JED) for a given moon phase in a specific cycle.
     *
     * Greg Miller gmiller@gregmiller.net
     * Algorithm from Meeus Astronomical Algorithms for computing dates of moon phases
     *
     *
     * This function computes the Julian Ephemeris Day (JED) for a specified moon phase
     * (new moon, first quarter, full moon, or last quarter) within a given cycle number.
     * The calculations are based on formulas from Jean Meeus's Astronomical Algorithms.
     * The function accounts for various astronomical parameters and corrections to
     * accurately determine the JED for the specified phase.
     *
     * @param cycle - The cycle number for which to calculate the moon phase.
     * @param phase - The moon phase to calculate (0 = new, 0.25 = first quarter,
     *                0.5 = full, 0.75 = last quarter).
     * @returns The Julian Ephemeris Day (JED) corresponding to the specified moon phase
     *          within the given cycle.
     */
    private phaseDate;
    /**
     * Calculate the Julian Date of different moon phases for a given year and month.
     *
     * This function computes the Julian Date for the new moon, first quarter, full moon,
     * and last quarter phases of the moon for a specific year and month.
     *
     * @param year - The year for which the moon phases are calculated.
     * @param month - The month (0-indexed) for which the moon phases are calculated.
     * @returns An object containing the Julian Dates for the new moon, first quarter,
     *          full moon, and last quarter phases.
     */
    moon_phases(year: number, month: number): {
        newMoon: number;
        firstQuarter: number;
        fullMoon: number;
        lastQuarter: number;
    };
    /**
     * Compute the dates of full moon for the given year and timezone.
     *
     * @param year - The year to compute the full moon dates for.
     * @param tz - Optional timezone string. Defaults to "Asia/Yangon".
     * @returns An array of 12 strings, each representing the date of the full moon for each month of the year.
     */
    fullmoon_day(year: number, tz?: TimeZones): string[];
    /**
     * Return the moon age in days, length of month, previous and next new moon days in strings,
     * and the full moon day in string.
     * @param tz - Optional time zone. Defaults to "GMT".
     * @returns Object containing duration, moon age, previous and next new moon days,
     * and the full moon day.
     */
    moon_age(tz?: TimeZones): {
        duration: number;
        moonAge: number;
        previousNewMoon: string;
        nextNewMoon: string;
        fullMoon: string;
    };
    /**
     * Get string representations of moon phase dates for a given month and year.
     *
     * This function calculates the dates of the new moon, first quarter,
     * full moon, and last quarter for the specified year and month, and
     * returns them as formatted string representations.
     *
     * @param year - The year for which to calculate moon phases.
     * @param month - The month for which to calculate moon phases.
     * @returns An object containing the string representations of the
     * new moon, first quarter, full moon, and last quarter dates.
     */
    moon_phaseStr(year: number, month: number): {
        newMoon: string;
        firstQuarter: string;
        fullMoon: string;
        lastQuarter: string;
    };
    /**
     * A more recent lunation number (called the Lunation Number) was introduced by Jean Meeus in 1998.
     * Lunation 0 as beginning on the first new moon of 2000 (this occurred at approximately 18:14 UTC, 6 January 2000).
     *
     * @param year - The year for which to calculate moon phases.
     * @param month - The month for which to calculate moon phases [0=Jan,...,11=Dec]
     * @returns - Meenus Lunation Number [LN]
     */
    meenus_ln(year: number, month: number): number;
    /**
     * Brown Lunation Number (BLN) by Ernest William Brown.
     * Lunation 1 occurred at approximately 02:41 UTC, 17 January 1923.
     *
     * @param year - The year for which to calculate moon phases.
     * @param month  - The month for which to calculate moon phases [0=Jan,...,11=Dec]
     * @returns - Brown Lunation Number [BLN] [BLN = LN + 953]
     */
    brown_ln(year: number, month: number): number;
    /**
     * The Thai Lunation Number is called "มาสเกณฑ์" (Maasa-Kendha),
     * defines lunation 0 as the beginning of Burmese era of the Buddhist calendar on Sunday, 22 March 638 CE.
     *
     * @param year - The year for which to calculate moon phases.
     * @param month  - The month for which to calculate moon phases [0=Jan,...,11=Dec]
     * @returns Thai Lunation Number [TLN] [TLN = LN + 16843]
     */
    thai_ln(year: number, month: number): number;
}
/*!
The Algorithm for calculation of Burmese Calendar (Myanmar Calendar) by Dr. Yan Naing Aye.
Reference: https://cool-emerald.blogspot.com/2013/06/algorithm-program-and-calculation-of.html
 */
export declare class BurmeseCal {
    private _lang;
    private _year;
    private month_;
    private _date;
    private is_now;
    private cal;
    /**
     * Get the Burmese calendar data for a given Gregorian year.
     *
     * The method takes a Gregorian year and an optional language setting and
     * returns the corresponding Burmese calendar data for that year.
     *
     * @param year - The Gregorian year.
     * @param lang - Optional language setting for the year view. Defaults to "English".
     * @returns The Burmese calendar data for the given year.
     */
    yearView({ year, lang }: YearViewOptions): YearViewObject;
    /**
     * Get the Burmese calendar data for a given Gregorian month.
     *
     * The method takes a Gregorian year, month and an optional language setting and
     * returns the corresponding Burmese calendar data for that month.
     *
     * @param year - The Gregorian year.
     * @param month - The Gregorian month (1-12).
     * @param lang - Optional language setting for the month view. Defaults to "English".
     * @returns The Burmese calendar data for the given month.
     */
    monthView({ year, month, lang, }: MontnViewOptions): MonthViewObject;
    /**
     * Get the Burmese calendar data for a specific day in a given Gregorian month and year.
     *
     * The method takes a Gregorian year, month, day, and an optional language setting,
     * and returns the corresponding Burmese calendar data for that specific day.
     *
     * @param year - The Gregorian year.
     * @param month - The Gregorian month (1-12).
     * @param day - The Gregorian day (1-31).
     * @param lang - Optional language setting for the day view. Defaults to "English".
     * @returns The Burmese calendar data for the given day.
     */
    dayView({ year, month, day, lang, }: DayViewOptions): DayViewObject;
    /**
     * Calculate the Thingyan festival times for a given Burmese year.
     *
     * This method computes the Julian Dates and Julian Day Numbers for the
     * Atat and Akya times during the Thingyan festival for a specified
     * Burmese year. The Thingyan festival marks the Burmese New Year and
     * occurs annually.
     *
     * @param by - The Burmese year for which Thingyan times are calculated.
     * @returns An object containing:
     *  - ja: Julian Date of Atat Time for the given year.
     *  - jk: Julian Date of Akya Time for the given year.
     *  - da: Julian Day Number of Atat Time for the given year.
     *  - dk: Julian Day Number of Akya Time for the given year.
     * @throws Will throw an error if the Burmese year is before 1100,
     *         as Thingyan calculations are not applicable.
     */
    private thingyanTime;
    private thingyanDays;
    private thingyanFromG;
    /**
     * Calculates the Thingyan festival dates and times for the given year.
     *
     * The method takes two parameters: the year and the year type. The year
     * type can be either "Burmese" or "Gregorian". If the year type is not
     * provided, the default value is "Gregorian". If the year type is "Burmese",
     * the method returns the Thingyan festival dates and times for the given
     * Burmese year. If the year type is "Gregorian", the method returns the
     * Thingyan festival dates and times for the given Gregorian year.
     *
     * @param year - The year to be calculated.
     * @param yearType - The year type. The default value is "Gregorian".
     * @returns An object with the following properties:
     *   - YearFrom: The Burmese year that the festival starts.
     *   - YearTo: The Burmese year that the festival ends.
     *   - AkyoDay: The day of the first day of the festival.
     *   - AkyaDayTime: The time of the first day of the festival.
     *   - AkyatDay: The day of the second day of the festival.
     *   - AkyatDay2: The day of the third day of the festival.
     *   - AtatDayTime: The time of the third day of the festival.
     *   - NewYearDay: The day of the New Year Day following the festival.
     *   - akyatday2: A boolean indicating whether the third day of the festival
     *     falls on the same day as the New Year Day.
     */
    thingyan(year: number, yearType?: "Burmese" | "Gregorian"): ThinGyan;
    /**
     * Gets the Burmese year type for the given year.
     *
     * The method takes a Burmese year and an optional language setting and
     * returns the corresponding year type in the specified language.
     *
     * @param by - The Burmese year.
     * @param lang - Optional language setting for the year type. Defaults to "English".
     * @returns The Burmese year type in the specified language.
     */
    burmeseYearType(by: number, lang?: Language): string;
    /**
     * Converts a given date and time to the Julian Date and Julian Day Number.
     *
     * This method takes a specified date and time, including the time zone,
     * and calculates the corresponding Julian Date (jd) and Julian Day Number (jdn).
     *
     * @param year - The year of the date.
     * @param month - The month of the date [1=Jan,...,12=Dec].
     * @param day - The day of the month.
     * @param hour - The hour of the day (default is 12).
     * @param minutes - The minutes past the hour (default is 0).
     * @param seconds - The seconds past the minute (default is 0).
     * @param tz - The time zone of the date and time (default is "GMT").
     * @returns An object containing:
     *  - jd: The calculated Julian Date.
     *  - jdn: The calculated Julian Day Number.
     */
    datetimeToJd({ year, month, day, hour, minutes, seconds, tz, }: G2JOptions): {
        jd: number;
        jdn: number;
    };
    /**
     * Converts a Julian Date (jd) to a datetime object.
     * @param jd - The Julian Date to be converted.
     * @param tz - Optional time zone setting for the datetime object. Defaults to "GMT".
     * @returns An object with the year, month, day, hour, minutes and seconds of the datetime object.
     */
    jdToDatetime(jd: number, tz?: TimeZones): {
        year: number;
        month: number;
        day: number;
        hour: number;
        minutes: number;
        seconds: number;
    };
    /**
     * Convert a date between Gregorian and Julian calendars.
     *
     * This method takes an object with the following properties:
     *   - ct: The calendar type to convert to. Either "julian" or "gregorian".
     *   - year: The year to be converted.
     *   - month: The month to be converted [1=Jan,...,12=Dec].
     *   - day: The day to be converted [1-31].
     *
     * The method returns an object with the year, month and day of the converted
     * date.
     */
    calendarConverter({ ct, year, month, day }: CalendarConvertOptions): {
        year: number;
        month: number;
        day: number;
    };
}
